@@ -5,6 +5,10 @@ global.process = null
 delete require.cache[require.resolve('../../')]
 onSignalExit = require('../../')
 
-onSignalExit(function (code, signal) {
+var unwrap = onSignalExit(function (code, signal) {
   throw new Error('this should not ever be called')
 })
+
+if (typeof unwrap !== 'function') {
+  throw new Error('missing unwrap function')
+}
